Crate spectral_density

Crate spectral_density 

Structs

Welch
WelchResult

Enums

DetrendingMethod
An enumeration that specifies the method used to estimate and remove the trend from a signal.
ScalingMethod
SpectralError
WelchWindow
Represents the available window functions for use in Welch’s method.

Functions

welch_f32
Computes the Power Spectral Density (PSD) or Power Spectrum of a signal using Welch’s method for single-precision floating-point (f32) data.
welch_f64
Computes the Power Spectral Density (PSD) or Power Spectrum of a signal using Welch’s method for double-precision floating-point (f64) data.